@@ -22,8 +22,5 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__version__ = "1.4.1"
-__author__ = "Guard Boi"
-__email__ = "guard@cow.futbol"
-__description__ = "Generates a random seal image for py-cord"
-__licence__ = "MIT"
\ No newline at end of file
+
+from .client import Client, __author__, __description__, __licence__, __version__
\ No newline at end of file
